summaryrefslogtreecommitdiffstats
path: root/filesharing/advanced/kcm_sambaconf/smbpasswdfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'filesharing/advanced/kcm_sambaconf/smbpasswdfile.h')
-rw-r--r--filesharing/advanced/kcm_sambaconf/smbpasswdfile.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/filesharing/advanced/kcm_sambaconf/smbpasswdfile.h b/filesharing/advanced/kcm_sambaconf/smbpasswdfile.h
index 2542d3f6..88eb8594 100644
--- a/filesharing/advanced/kcm_sambaconf/smbpasswdfile.h
+++ b/filesharing/advanced/kcm_sambaconf/smbpasswdfile.h
@@ -34,7 +34,7 @@
*@author Jan Schäfer
*/
-#include <qstring.h>
+#include <tqstring.h>
#include <kurl.h>
class SambaFile;
@@ -46,9 +46,9 @@ class KProcess;
class SambaUser
{
public:
- SambaUser(const QString & aName = QString::null, int anUid = -1) {name = aName; uid = anUid;};
+ SambaUser(const TQString & aName = TQString::null, int anUid = -1) {name = aName; uid = anUid;};
- QString name;
+ TQString name;
int uid;
int gid;
bool isUserAccount;
@@ -58,12 +58,12 @@ public:
};
/**
* A QPtrList of SambaUser
**/
-class SambaUserList : public QPtrList<SambaUser>
+class SambaUserList : public TQPtrList<SambaUser>
{
public:
- QStringList getUserNames();
+ TQStringList getUserNames();
};
/**
@@ -92,13 +92,13 @@ public:
/**
* Calls smbpasswd with the given arguments
**/
- bool executeSmbpasswd(const QStringList & args);
+ bool executeSmbpasswd(const TQStringList & args);
/**
* Tries to add the passed user to the smbpasswd file
* returns true if successful otherwise false
**/
- bool addUser(const SambaUser &, const QString & password);
+ bool addUser(const SambaUser &, const TQString & password);
/**
* Tries to remove the passed user from the smbpasswd file
@@ -110,7 +110,7 @@ public:
* Tries to change the password of the passed user
* if it fails returns false otherwise true
**/
- bool changePassword(const SambaUser &, const QString & password);
+ bool changePassword(const SambaUser &, const TQString & password);
bool enableUser(const SambaUser &);
@@ -120,7 +120,7 @@ public:
bool setMachineTrustAccount(const SambaUser &);
- bool joinADomain(const QString &, const QString &, const QString &, const QString &);
+ bool joinADomain(const TQString &, const TQString &, const TQString &, const TQString &);
/**
* Returns the Url of the smbpasswd file
@@ -132,7 +132,7 @@ public:
static KURL getUrlFromSambaFile(const SambaFile *file);
protected:
KURL _url;
- QString _smbpasswdOutput;
+ TQString _smbpasswdOutput;
protected slots:
void smbpasswdStdOutReceived(KProcess*,char*,int);
@@ -58,12 +58,12 @@ public:
};
/**
- * A QPtrList of SambaUser
+ * A TQPtrList of SambaUser
**/